---
name: Suggestions / 功能建议 about: 让我们了解你的需求 title: CEP.[Number]
labels: enhancement assignees: ''

---

**需求/request**

> 请在此处详细描述你的诉求/这样做的理由 / The reason why should I add the function to this framework

**最终表现效果 / result**
> 请在此处描述你的功能的最终表现效果
